@@ -57,7 +57,6 @@ class DockerBackend:
         return d
 
     def up(self, container_config: ContainerConfig) -> str:
-
         """
         Create container based on simulation and threedimodel.
 
@@ -80,7 +79,9 @@ class DockerBackend:
             )
 
         if container_config.debugpy_port is not None:
-            ports = {f'{container_config.debugpy_port}/tcp': container_config.debugpy_port}
+            ports = {
+                f"{container_config.debugpy_port}/tcp": container_config.debugpy_port
+            }
             _envs.update(
                 {f"DEBUGPY": "1", "DEBUGPY_PORT": str(container_config.debugpy_port)}
             )
