@@ -32,6 +32,7 @@ from hikaru.model.rel_1_20 import (
     NodeSelectorTerm,
     NodeSelector,
     NodeSelectorRequirement,
+    EmptyDirVolumeSource
 )
 
 
@@ -172,7 +173,7 @@ def get_simulation_job(cfg: KubernetesJobConfig) -> Job:
                             ),
                         )
                         for mount in cfg.mount_points
-                    ],
+                    ] + [Volume(name='shared-data', emptyDir=EmptyDirVolumeSource())],
                     restartPolicy="Never",
                 ),
             ),
