@@ -258,7 +258,7 @@ class KubernetesJobConfig:
             + self.scheduler_config.mount_points
             + self.simulation_config.mount_points
         ):
-            if mount_point not in mount_points:
+            if mount_point not in mount_points and mount_point.name != 'shared-data':
                 mount_points.append(mount_point)
         return mount_points
 
